@@ -18,7 +18,7 @@ from typing import IO, Any, Dict, Mapping, Sequence, Type, Union
 from botocore.client import BaseClient, ClientMeta
 from botocore.response import StreamingBody
 
-from .literals import EnabledTypeType, IdentityProviderTypeType
+from .literals import AuthenticationTypeType, EnabledTypeType, IdentityProviderTypeType
 from .type_defs import (
     AssociateBrowserSettingsResponseTypeDef,
     AssociateNetworkSettingsResponseTypeDef,
@@ -218,6 +218,7 @@ class WorkSpacesWebClient(BaseClient):
         self,
         *,
         additionalEncryptionContext: Mapping[str, str] = ...,
+        authenticationType: AuthenticationTypeType = ...,
         clientToken: str = ...,
         customerManagedKey: str = ...,
         displayName: str = ...,
@@ -616,7 +617,11 @@ class WorkSpacesWebClient(BaseClient):
         """
 
     def update_portal(
-        self, *, portalArn: str, displayName: str = ...
+        self,
+        *,
+        portalArn: str,
+        authenticationType: AuthenticationTypeType = ...,
+        displayName: str = ...
     ) -> UpdatePortalResponseTypeDef:
         """
         Updates a web portal.
