@@ -17,7 +17,12 @@ from typing import IO, Any, Dict, List, Mapping, Sequence, Union
 
 from botocore.response import StreamingBody
 
-from .literals import EnabledTypeType, IdentityProviderTypeType, PortalStatusType
+from .literals import (
+    AuthenticationTypeType,
+    EnabledTypeType,
+    IdentityProviderTypeType,
+    PortalStatusType,
+)
 
 if sys.version_info >= (3, 9):
     from typing import Literal
@@ -433,6 +438,7 @@ GetPortalRequestRequestTypeDef = TypedDict(
 PortalTypeDef = TypedDict(
     "PortalTypeDef",
     {
+        "authenticationType": AuthenticationTypeType,
         "browserSettingsArn": str,
         "browserType": Literal["Chrome"],
         "creationDate": datetime,
@@ -615,6 +621,7 @@ ListPortalsRequestRequestTypeDef = TypedDict(
 PortalSummaryTypeDef = TypedDict(
     "PortalSummaryTypeDef",
     {
+        "authenticationType": AuthenticationTypeType,
         "browserSettingsArn": str,
         "browserType": Literal["Chrome"],
         "creationDate": datetime,
@@ -810,6 +817,7 @@ _RequiredUpdatePortalRequestRequestTypeDef = TypedDict(
 _OptionalUpdatePortalRequestRequestTypeDef = TypedDict(
     "_OptionalUpdatePortalRequestRequestTypeDef",
     {
+        "authenticationType": AuthenticationTypeType,
         "displayName": str,
     },
     total=False,
@@ -1114,6 +1122,7 @@ CreatePortalRequestRequestTypeDef = TypedDict(
     "CreatePortalRequestRequestTypeDef",
     {
         "additionalEncryptionContext": Mapping[str, str],
+        "authenticationType": AuthenticationTypeType,
         "clientToken": str,
         "customerManagedKey": str,
         "displayName": str,
